==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/msg_compose.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="msg_compose.php" method="post">

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "msg_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="370" valign="top">
			<?php
			if (isset($display) && $display == "size_allocation_exceeded") {
			?>
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
			    <tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_size_allocation_exceeded'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_size_allocation_exceeded'];?></b><br />
					</td>
				</tr>
			</table>

			<?php
			}
			elseif (isset($display) && $display == "compose_allowed") {
			?>

			<table cellpadding="4" cellspacing="0" border="0" width="100%">
			    <tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_message'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<table>
							<tr>
								<td>
									<b><?php echo $lang['txt_to'];?></b>
								</td>
							</tr>
							<tr>
								<td>
								<?php
								if(!isset($to_user_id))
								{
								?>
								<select name="data[to_user_id]" class="formInput" />
								<?php
									foreach ($users as $key => $i) :
								?>
										<option value=<?php echo $i['user_id']?>><?php echo dots(50, $i['user_firstname'] . " " . $i['user_surname']);?></option>
								<?
									endforeach;
								?>
								</select>
								<?php
								}
								else {
								?>
									<input type="hidden" name="data[to_user_id]" value="<?php echo $to_user_id?>" />
									<?php echo $to_user['user_firstname']?> <?php echo $to_user['user_surname']?><br />
								<?
								}
								?>
								</td>
							</tr>
							<tr>
								<td>
									<b><?php echo $lang['txt_subject'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<input name="data[message_subject]" type="text" size=50" value="<?php echo $message['message_subject'];?>" class="formInput" /><br />
								</td>
							</tr>
							<tr>
								<td>
									<b><?php echo $lang['txt_body'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<textarea name="data[message_body]" cols="52" rows="10" class="formInput" /><?php echo $message['message_body'];?></textarea><br />
								</td>
							</tr>
							<tr>
								<td align="right">
									<input name="preview_message" type="submit" value="<?php echo $lang['sub_preview'];?>" class="formInput" />&nbsp;&nbsp;
								<input name="send_message" type="submit" value="<?php echo $lang['sub_send'];?>" class="formInput" /><br />
								</td>
							</tr>
						</table>

					</td>
				</tr>
			</table>

			<?php
			}
			elseif (isset($display) && $display == "preview_msg") {
			?>
			<input type="hidden" name="data[to_user_id]" value="<?php echo $to_user_id?>" />
			<input type="hidden" name="data[to_user]" value="<?php echo $to_user?>" />
			<input type="hidden" name="data[message_body]" value="<?php echo $message['message_body'];?>" />
			<input type="hidden" name="data[message_subject]" value="<?php echo $message['message_subject'];?>" />

			<table cellpadding="4" cellspacing="0" border="0" width="100%">
			    <tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_message'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<table>
							<tr>
								<td>
									<b><?php echo $lang['txt_to'];?></b>
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $to_user['user_firstname']?> <?php echo $to_user['user_surname']?><br />

								</td>
							</tr>
							<tr>
								<td>
									<b><?php echo $lang['txt_subject'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $message['message_subject'];?><br />
								</td>
							</tr>
							<tr>
								<td>
									<b><?php echo $lang['txt_body'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $message['message_body_display'];?>
								</td>
							</tr>
							<tr>
								<td align="right">
									<input name="edit_message_again" type="submit" value="<?php echo $lang['sub_edit'];?>" class="formInput" />&nbsp;&nbsp;
									<input name="send_message" type="submit" value="<?php echo $lang['sub_send'];?>" class="formInput" /><br />
								</td>
							</tr>
						</table>

					</td>
				</tr>
			</table>

			<?php
			}
			else { //we are not allowed to send to this person
			?>
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
			    <tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_im_deny_send'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_im_deny_send'];?><br />
					</td>
				</tr>
			</table>

			<?php
			}
			?>

		</td>

		<td width="20">&nbsp;</td>

		<td width="180" valign="top">
			<table border="0" width="100%" cellspacing="0" cellpadding="4">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_friends'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top" class="txt_footer">
						<?php
							if (isset($friends[0])) {
							foreach ($friends as $key => $i) :
						?>
								<a href="msg_compose.php?to_user_id=<?php echo $i['user_id']?>"><?php echo $i['user_firstname']?> <?php echo $i['user_surname']?></a><br />
						<?
							endforeach;
							}
							else {
								echo $lang['err_no_friends'];
							}
						?>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['hdr_message_statistics'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td class="txt_footer" colspan="3">
						<?php echo $lang['txt_message_statistics'];?><br />
					</td>
				</tr>
				<?php
				$percentage_used = floor((100/$message_statistics['total_size_allowed']) * $message_statistics['total_size']);
				if ($percentage_used > 100) {
				    $percentage_used = 100;
				}
				?>
				<tr>
					<td colspan="3">
						<table border="0" cellspacing="0" cellpadding="0" width="100%">
							<tr>
								<?php if($percentage_used>0) {?>
								<td width="<?php echo $percentage_used;?>%" class="bg1">
									<img src=<?php echo $templatePath;?>img/pixel.png width="1" height="7" alt="" /><br />
								</td>
								<?php }?>
								<td class="bg2">
									<img src=<?php echo $templatePath;?>img/pixel.png width="1" height="7" alt="" /><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td class="txt_footer" align="right" colspan="3">
						<?php echo $percentage_used;?>% used<br />
					</td>
				</tr>
				<tr>
					<td>
						<table width="100%" cellpadding="1" cellspacing="0" border="0">
			    			<tr>
								<td class="txt_footer">
									<b><?php echo $lang['txt_box'];?></b><br />
								</td>
								<td class="txt_footer">
									<b><?php echo $lang['txt_messages'];?></b><br />
								</td>
								<td class="txt_footer">
									<b><?php echo $lang['txt_size'];?></b><br />
								</td>
							</tr>

							<tr>
								<td class="txt_footer">
									<?php echo $lang['txt_box_in'];?><br />
								</td>
								<td class="txt_footer">
									<?php echo $message_statistics['in_box_messages'];?>&nbsp;(<?php echo $message_statistics['unread'];?>)<br />
								</td>
								<td class="txt_footer">
									<?php echo $message_statistics['in_box_size'];?><br />
								</td>
							</tr>
							<tr>
								<td class="txt_footer">
									<?php echo $lang['txt_box_out'];?><br />
								</td>
								<td class="txt_footer">
									<?php echo $message_statistics['out_box_messages'];?><br />
								</td>
								<td class="txt_footer">
									<?php echo $message_statistics['out_box_size'];?><br />
								</td>
							</tr>
							<tr>
								<td class="txt_footer">
									<?php echo $lang['txt_box_save'];?><br />
								</td>
								<td class="txt_footer">
									<?php echo $message_statistics['save_box_messages'];?><br />
								</td>
								<td class="txt_footer">
									<?php echo $message_statistics['save_box_size'];?><br />
								</td>
							</tr>
							<tr>
								<td class="txt_footer">
									<?php echo $lang['txt_totals'];?><br />
								</td>
								<td class="txt_footer">
									<b><?php echo $message_statistics['total_messages'];?></b><br />
								</td>
								<td class="txt_footer">
									<b><?php echo $message_statistics['total_size'];?></b><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
</form>

==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/msg_compose.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="msg_compose.php" method="post">

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "msg_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="370" valign="top">
			<?php
			if (isset($display) && $display == "size_allocation_exceeded") {
			?>
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
			    <tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_size_allocation_exceeded'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_size_allocation_exceeded'];?></b><br />
					</td>
				</tr>
			</table>

			<?php
			}
			elseif (isset($display) && $display == "compose_allowed" && !empty($users)) {
			?>

			<table cellpadding="4" cellspacing="0" border="0" width="100%">
			    <tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_message'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<table>
							<tr>
								<td>
									<b><?php echo $lang['txt_to'];?></b>
								</td>
							</tr>
							<tr>
								<td>
								<?php
								if(!isset($to_user_id))
								{
								?>
								<select name="data[to_user_id]" class="formInput" />
								<?php
									foreach ($users as $key => $i) :
								?>
										<option value=<?php echo $i['user_id']?>><?php echo dots(50, $i['profile_nic']);?></option>
								<?
									endforeach;
								?>
								</select>
								<?php
								}
								else {
								?>
									<input type="hidden" name="data[to_user_id]" value="<?php echo $to_user_id?>" />
									<?php echo $to_user['profile_nic']?><br />
								<?
								}
								?>
								</td>
							</tr>
							<tr>
								<td>
									<b><?php echo $lang['txt_subject'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<input name="data[message_subject]" type="text" size=50" value="<?php echo $message['message_subject'];?>" class="formInput" /><br />
								</td>
							</tr>
							<tr>
								<td>
									<b><?php echo $lang['txt_body'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<textarea name="data[message_body]" cols="52" rows="10" class="formInput" /><?php echo $message['message_body'];?></textarea><br />
								</td>
							</tr>
							<tr>
								<td align="right">
									<input name="preview_message" type="submit" value="<?php echo $lang['sub_preview'];?>" class="formInput" />&nbsp;&nbsp;
								<input name="send_message" type="submit" value="<?php echo $lang['sub_send'];?>" class="formInput" /><br />
								</td>
							</tr>
						</table>

					</td>
				</tr>
			</table>

			<?php
			}
			elseif (isset($display) && $display == "preview_msg") {
			?>
			<input type="hidden" name="data[to_user_id]" value="<?php echo $to_user_id?>" />
			<input type="hidden" name="data[to_user]" value="<?php echo $to_user?>" />
			<input type="hidden" name="data[message_body]" value="<?php echo $message['message_body'];?>" />
			<input type="hidden" name="data[message_subject]" value="<?php echo $message['message_subject'];?>" />

			<table cellpadding="4" cellspacing="0" border="0" width="100%">
			    <tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_message'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<table>
							<tr>
								<td>
									<b><?php echo $lang['txt_to'];?></b>
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $to_user['profile_nic']?><br />

								</td>
							</tr>
							<tr>
								<td>
									<b><?php echo $lang['txt_subject'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $message['message_subject'];?><br />
								</td>
							</tr>
							<tr>
								<td>
									<b><?php echo $lang['txt_body'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $message['message_body_display'];?>
								</td>
							</tr>
							<tr>
								<td align="right">
									<input name="edit_message_again" type="submit" value="<?php echo $lang['sub_edit'];?>" class="formInput" />&nbsp;&nbsp;
									<input name="send_message" type="submit" value="<?php echo $lang['sub_send'];?>" class="formInput" /><br />
								</td>
							</tr>
						</table>

					</td>
				</tr>
			</table>
			<?php
			}
			elseif (empty($users))  {
			?>
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
			    <tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_message'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php echo $lang['err_no_friends'];?><br />
					</td>
				</tr>
			</table>
			<?php
			}
			else { //we are not allowed to send to this person
			?>
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
			    <tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_im_deny_send'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_im_deny_send'];?><br />
					</td>
				</tr>
			</table>

			<?php
			}
			?>

		</td>

		<td width="20">&nbsp;</td>

		<td width="180" valign="top">
			<?php
			if (isset($users)) {
			?>
			<table border="0" width="100%" cellspacing="0" cellpadding="4">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_friends'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php
							foreach ($users as $key => $i) :
						?>
								<a href="msg_compose.php?to_user_id=<?php echo $i['user_id']?>"><?php echo $i['profile_nic']?></a><br />
						<?php
							endforeach;
						?>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<?php }?>
						
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['hdr_message_statistics'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="2" border="0" class="picture">
			    			<tr>
								<td class="bg2">
									<span class="txt_footer">
									<b><?php echo $lang['txt_box'];?></b><br />
									</span>
								</td>
								<td class="bg2">
									<span class="txt_footer">
									<b><?php echo $lang['txt_messages'];?></b><br />
									</span>
								</td>
								<td class="bg2">
									<span class="txt_footer">
									<b><?php echo $lang['txt_size'];?></b><br />
									</span>
								</td>
							</tr>

							<tr>
								<td class="bg3">
									<span class="txt_footer">
									<?php echo $lang['txt_box_in'];?><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<?php echo $message_statistics['in_box_messages'];?>&nbsp;(<?php echo $message_statistics['unread'];?>)<br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<?php echo $message_statistics['in_box_size'];?><br />
									</span>
								</td>
							</tr>
							<tr>
								<td class="bg3">
									<span class="txt_footer">
									<?php echo $lang['txt_box_out'];?><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<?php echo $message_statistics['out_box_messages'];?><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<?php echo $message_statistics['out_box_size'];?><br />
									</span>
								</td>
							</tr>
							<tr>
								<td class="bg3">
									<span class="txt_footer">
									<?php echo $lang['txt_box_save'];?><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<?php echo $message_statistics['save_box_messages'];?><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<?php echo $message_statistics['save_box_size'];?><br />
									</span>
								</td>
							</tr>
							<tr>
								<td class="bg3">
									<span class="txt_footer">
									<?php echo $lang['txt_totals'];?><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<b><?php echo $message_statistics['total_messages'];?></b><br />
									</span>
								</td>
								<td class="bg4">
									<span class="txt_footer">
									<b><?php echo $message_statistics['total_size'];?></b><br />
									</span>
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<?php
				$percentage_used = floor((100/$message_statistics['total_size_allowed']) * $message_statistics['total_size']);
				if ($percentage_used > 100) {
				    $percentage_used = 100;
				}
				?>
				<tr>
					<td colspan="3">
						<table border="0" cellspacing="2" cellpadding="0" width="100%" class="picture">
							<tr>
								<?php if($percentage_used>0) {?>
								<td width="<?php echo $percentage_used;?>%" class="bg1">
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="7" alt="" /><br />
								</td>
								<?php }?>
								<td class="bg2">
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="7" alt="" /><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td class="txt_footer" align="right" colspan="3">
						<?php echo $percentage_used;?>&#37; used<br />
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
</form>
